require 'fast_excel'

module Dependency 
  class ExcelGenerator
    attr_accessor :workbook
    attr_accessor :worksheet
  
    def create_excel(target_label)
      filename = "#{target_label}_dependency_list.xlsx" 
      File.delete(filename) if File.file?(filename)

      @workbook = FastExcel.open(filename, constant_memory: true)
      @worksheet = workbook.add_worksheet("cocoapods-dependency-list")
      @worksheet.auto_width = true
    end

    def create_title()
      @worksheet.append_row(["module name", "local", "source", "version", "homepage", "summary"], @workbook.bold_format)
    end

    def create_row(spec) 
      return unless spec.source
      local = spec.local? if spec.source
      summary = spec.root.attributes_hash['summary']
      worksheet << [spec.module_name, local, spec.source, spec.version, spec.homepage, summary]
    end

    # @param [Array<Specification>] specs a list specification
    def create_content(specs) 
      specs.each { | spec | 
        create_row(spec)
      } 
    end

    def close_excel 
      @workbook.close
    end
    
    # @param  [UmbrellaTargetDescription] umbrella_target the CocoaPods umbrella targets generated by the installer.
    # @param  [Hash{<String, Specification>}] module_spec_hash 
    #
    def generate(umbrella_target, module_spec_hash)
      create_excel(umbrella_target.cocoapods_target_label)
      create_title
      create_content(umbrella_target.specs)
      close_excel
    end 
  end
end
